# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageGridPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkChangeInformationImageFilterPython
else:
    import _itkChangeInformationImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageToImageFilterAPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImagePython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython

def itkChangeInformationImageFilterIF2_New():
    return itkChangeInformationImageFilterIF2.New()

class itkChangeInformationImageFilterIF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkChangeInformationImageFilterIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkChangeInformationImageFilterIF2_Pointer"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkChangeInformationImageFilterIF2_Pointer"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_Clone(self)

    def SetReferenceImage(self, image):
        r"""
        SetReferenceImage(self, image)

        Parameters
        ----------
        image: itkImageF2 *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_SetReferenceImage(self, image)

    def GetModifiableReferenceImage(self):
        r"""GetModifiableReferenceImage(self) -> itkImageF2"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GetModifiableReferenceImage(self)

    def GetReferenceImage(self, *args):
        r"""
        GetReferenceImage(self) -> itkImageF2
        GetReferenceImage(self) -> itkImageF2
        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GetReferenceImage(self, *args)

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GetUseReferenceImage(self)

    def SetOutputSpacing(self, _arg):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_SetOutputSpacing(self, _arg)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD2"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GetOutputSpacing(self)

    def SetOutputOrigin(self, _arg):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_SetOutputOrigin(self, _arg)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD2"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GetOutputOrigin(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD22"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GetOutputDirection(self)

    def GetOutputOffset(self):
        r"""GetOutputOffset(self) -> itkOffset2"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GetOutputOffset(self)

    def SetOutputOffset(self, *args):
        r"""
        SetOutputOffset(self, _arg)

        Parameters
        ----------
        _arg: itkOffset2

        SetOutputOffset(self, data)

        Parameters
        ----------
        data: long *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_SetOutputOffset(self, *args)

    def ChangeAll(self):
        r"""ChangeAll(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_ChangeAll(self)

    def ChangeNone(self):
        r"""ChangeNone(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_ChangeNone(self)

    def SetChangeSpacing(self, _arg):
        r"""
        SetChangeSpacing(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_SetChangeSpacing(self, _arg)

    def ChangeSpacingOn(self):
        r"""ChangeSpacingOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_ChangeSpacingOn(self)

    def ChangeSpacingOff(self):
        r"""ChangeSpacingOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_ChangeSpacingOff(self)

    def GetChangeSpacing(self):
        r"""GetChangeSpacing(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GetChangeSpacing(self)

    def SetChangeOrigin(self, _arg):
        r"""
        SetChangeOrigin(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_SetChangeOrigin(self, _arg)

    def ChangeOriginOn(self):
        r"""ChangeOriginOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_ChangeOriginOn(self)

    def ChangeOriginOff(self):
        r"""ChangeOriginOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_ChangeOriginOff(self)

    def GetChangeOrigin(self):
        r"""GetChangeOrigin(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GetChangeOrigin(self)

    def SetChangeDirection(self, _arg):
        r"""
        SetChangeDirection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_SetChangeDirection(self, _arg)

    def ChangeDirectionOn(self):
        r"""ChangeDirectionOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_ChangeDirectionOn(self)

    def ChangeDirectionOff(self):
        r"""ChangeDirectionOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_ChangeDirectionOff(self)

    def GetChangeDirection(self):
        r"""GetChangeDirection(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GetChangeDirection(self)

    def SetChangeRegion(self, _arg):
        r"""
        SetChangeRegion(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_SetChangeRegion(self, _arg)

    def ChangeRegionOn(self):
        r"""ChangeRegionOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_ChangeRegionOn(self)

    def ChangeRegionOff(self):
        r"""ChangeRegionOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_ChangeRegionOff(self)

    def GetChangeRegion(self):
        r"""GetChangeRegion(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GetChangeRegion(self)

    def SetCenterImage(self, _arg):
        r"""
        SetCenterImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_SetCenterImage(self, _arg)

    def CenterImageOn(self):
        r"""CenterImageOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_CenterImageOn(self)

    def CenterImageOff(self):
        r"""CenterImageOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_CenterImageOff(self)

    def GetCenterImage(self):
        r"""GetCenterImage(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GetCenterImage(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GenerateInputRequestedRegion(self)

    def GenerateData(self):
        r"""GenerateData(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_GenerateData(self)
    __swig_destroy__ = _itkChangeInformationImageFilterPython.delete_itkChangeInformationImageFilterIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkChangeInformationImageFilterIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkChangeInformationImageFilterIF2

        Create a new object of the class itkChangeInformationImageFilterIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkChangeInformationImageFilterIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkChangeInformationImageFilterIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkChangeInformationImageFilterIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkChangeInformationImageFilterIF2 in _itkChangeInformationImageFilterPython:
_itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF2_swigregister(itkChangeInformationImageFilterIF2)

def itkChangeInformationImageFilterIF3_New():
    return itkChangeInformationImageFilterIF3.New()

class itkChangeInformationImageFilterIF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkChangeInformationImageFilterIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkChangeInformationImageFilterIF3_Pointer"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkChangeInformationImageFilterIF3_Pointer"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_Clone(self)

    def SetReferenceImage(self, image):
        r"""
        SetReferenceImage(self, image)

        Parameters
        ----------
        image: itkImageF3 *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_SetReferenceImage(self, image)

    def GetModifiableReferenceImage(self):
        r"""GetModifiableReferenceImage(self) -> itkImageF3"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GetModifiableReferenceImage(self)

    def GetReferenceImage(self, *args):
        r"""
        GetReferenceImage(self) -> itkImageF3
        GetReferenceImage(self) -> itkImageF3
        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GetReferenceImage(self, *args)

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GetUseReferenceImage(self)

    def SetOutputSpacing(self, _arg):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_SetOutputSpacing(self, _arg)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD3"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GetOutputSpacing(self)

    def SetOutputOrigin(self, _arg):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_SetOutputOrigin(self, _arg)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD3"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GetOutputOrigin(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD33"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GetOutputDirection(self)

    def GetOutputOffset(self):
        r"""GetOutputOffset(self) -> itkOffset3"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GetOutputOffset(self)

    def SetOutputOffset(self, *args):
        r"""
        SetOutputOffset(self, _arg)

        Parameters
        ----------
        _arg: itkOffset3

        SetOutputOffset(self, data)

        Parameters
        ----------
        data: long *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_SetOutputOffset(self, *args)

    def ChangeAll(self):
        r"""ChangeAll(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_ChangeAll(self)

    def ChangeNone(self):
        r"""ChangeNone(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_ChangeNone(self)

    def SetChangeSpacing(self, _arg):
        r"""
        SetChangeSpacing(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_SetChangeSpacing(self, _arg)

    def ChangeSpacingOn(self):
        r"""ChangeSpacingOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_ChangeSpacingOn(self)

    def ChangeSpacingOff(self):
        r"""ChangeSpacingOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_ChangeSpacingOff(self)

    def GetChangeSpacing(self):
        r"""GetChangeSpacing(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GetChangeSpacing(self)

    def SetChangeOrigin(self, _arg):
        r"""
        SetChangeOrigin(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_SetChangeOrigin(self, _arg)

    def ChangeOriginOn(self):
        r"""ChangeOriginOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_ChangeOriginOn(self)

    def ChangeOriginOff(self):
        r"""ChangeOriginOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_ChangeOriginOff(self)

    def GetChangeOrigin(self):
        r"""GetChangeOrigin(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GetChangeOrigin(self)

    def SetChangeDirection(self, _arg):
        r"""
        SetChangeDirection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_SetChangeDirection(self, _arg)

    def ChangeDirectionOn(self):
        r"""ChangeDirectionOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_ChangeDirectionOn(self)

    def ChangeDirectionOff(self):
        r"""ChangeDirectionOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_ChangeDirectionOff(self)

    def GetChangeDirection(self):
        r"""GetChangeDirection(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GetChangeDirection(self)

    def SetChangeRegion(self, _arg):
        r"""
        SetChangeRegion(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_SetChangeRegion(self, _arg)

    def ChangeRegionOn(self):
        r"""ChangeRegionOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_ChangeRegionOn(self)

    def ChangeRegionOff(self):
        r"""ChangeRegionOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_ChangeRegionOff(self)

    def GetChangeRegion(self):
        r"""GetChangeRegion(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GetChangeRegion(self)

    def SetCenterImage(self, _arg):
        r"""
        SetCenterImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_SetCenterImage(self, _arg)

    def CenterImageOn(self):
        r"""CenterImageOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_CenterImageOn(self)

    def CenterImageOff(self):
        r"""CenterImageOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_CenterImageOff(self)

    def GetCenterImage(self):
        r"""GetCenterImage(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GetCenterImage(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GenerateInputRequestedRegion(self)

    def GenerateData(self):
        r"""GenerateData(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_GenerateData(self)
    __swig_destroy__ = _itkChangeInformationImageFilterPython.delete_itkChangeInformationImageFilterIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkChangeInformationImageFilterIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkChangeInformationImageFilterIF3

        Create a new object of the class itkChangeInformationImageFilterIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkChangeInformationImageFilterIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkChangeInformationImageFilterIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkChangeInformationImageFilterIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkChangeInformationImageFilterIF3 in _itkChangeInformationImageFilterPython:
_itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIF3_swigregister(itkChangeInformationImageFilterIF3)

def itkChangeInformationImageFilterISS2_New():
    return itkChangeInformationImageFilterISS2.New()

class itkChangeInformationImageFilterISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkChangeInformationImageFilterISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkChangeInformationImageFilterISS2_Pointer"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkChangeInformationImageFilterISS2_Pointer"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_Clone(self)

    def SetReferenceImage(self, image):
        r"""
        SetReferenceImage(self, image)

        Parameters
        ----------
        image: itkImageSS2 *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_SetReferenceImage(self, image)

    def GetModifiableReferenceImage(self):
        r"""GetModifiableReferenceImage(self) -> itkImageSS2"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GetModifiableReferenceImage(self)

    def GetReferenceImage(self, *args):
        r"""
        GetReferenceImage(self) -> itkImageSS2
        GetReferenceImage(self) -> itkImageSS2
        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GetReferenceImage(self, *args)

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GetUseReferenceImage(self)

    def SetOutputSpacing(self, _arg):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_SetOutputSpacing(self, _arg)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD2"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GetOutputSpacing(self)

    def SetOutputOrigin(self, _arg):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_SetOutputOrigin(self, _arg)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD2"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GetOutputOrigin(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD22"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GetOutputDirection(self)

    def GetOutputOffset(self):
        r"""GetOutputOffset(self) -> itkOffset2"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GetOutputOffset(self)

    def SetOutputOffset(self, *args):
        r"""
        SetOutputOffset(self, _arg)

        Parameters
        ----------
        _arg: itkOffset2

        SetOutputOffset(self, data)

        Parameters
        ----------
        data: long *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_SetOutputOffset(self, *args)

    def ChangeAll(self):
        r"""ChangeAll(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_ChangeAll(self)

    def ChangeNone(self):
        r"""ChangeNone(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_ChangeNone(self)

    def SetChangeSpacing(self, _arg):
        r"""
        SetChangeSpacing(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_SetChangeSpacing(self, _arg)

    def ChangeSpacingOn(self):
        r"""ChangeSpacingOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_ChangeSpacingOn(self)

    def ChangeSpacingOff(self):
        r"""ChangeSpacingOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_ChangeSpacingOff(self)

    def GetChangeSpacing(self):
        r"""GetChangeSpacing(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GetChangeSpacing(self)

    def SetChangeOrigin(self, _arg):
        r"""
        SetChangeOrigin(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_SetChangeOrigin(self, _arg)

    def ChangeOriginOn(self):
        r"""ChangeOriginOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_ChangeOriginOn(self)

    def ChangeOriginOff(self):
        r"""ChangeOriginOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_ChangeOriginOff(self)

    def GetChangeOrigin(self):
        r"""GetChangeOrigin(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GetChangeOrigin(self)

    def SetChangeDirection(self, _arg):
        r"""
        SetChangeDirection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_SetChangeDirection(self, _arg)

    def ChangeDirectionOn(self):
        r"""ChangeDirectionOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_ChangeDirectionOn(self)

    def ChangeDirectionOff(self):
        r"""ChangeDirectionOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_ChangeDirectionOff(self)

    def GetChangeDirection(self):
        r"""GetChangeDirection(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GetChangeDirection(self)

    def SetChangeRegion(self, _arg):
        r"""
        SetChangeRegion(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_SetChangeRegion(self, _arg)

    def ChangeRegionOn(self):
        r"""ChangeRegionOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_ChangeRegionOn(self)

    def ChangeRegionOff(self):
        r"""ChangeRegionOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_ChangeRegionOff(self)

    def GetChangeRegion(self):
        r"""GetChangeRegion(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GetChangeRegion(self)

    def SetCenterImage(self, _arg):
        r"""
        SetCenterImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_SetCenterImage(self, _arg)

    def CenterImageOn(self):
        r"""CenterImageOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_CenterImageOn(self)

    def CenterImageOff(self):
        r"""CenterImageOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_CenterImageOff(self)

    def GetCenterImage(self):
        r"""GetCenterImage(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GetCenterImage(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GenerateInputRequestedRegion(self)

    def GenerateData(self):
        r"""GenerateData(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_GenerateData(self)
    __swig_destroy__ = _itkChangeInformationImageFilterPython.delete_itkChangeInformationImageFilterISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkChangeInformationImageFilterISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkChangeInformationImageFilterISS2

        Create a new object of the class itkChangeInformationImageFilterISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkChangeInformationImageFilterISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkChangeInformationImageFilterISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkChangeInformationImageFilterISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkChangeInformationImageFilterISS2 in _itkChangeInformationImageFilterPython:
_itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS2_swigregister(itkChangeInformationImageFilterISS2)

def itkChangeInformationImageFilterISS3_New():
    return itkChangeInformationImageFilterISS3.New()

class itkChangeInformationImageFilterISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkChangeInformationImageFilterISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkChangeInformationImageFilterISS3_Pointer"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkChangeInformationImageFilterISS3_Pointer"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_Clone(self)

    def SetReferenceImage(self, image):
        r"""
        SetReferenceImage(self, image)

        Parameters
        ----------
        image: itkImageSS3 *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_SetReferenceImage(self, image)

    def GetModifiableReferenceImage(self):
        r"""GetModifiableReferenceImage(self) -> itkImageSS3"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GetModifiableReferenceImage(self)

    def GetReferenceImage(self, *args):
        r"""
        GetReferenceImage(self) -> itkImageSS3
        GetReferenceImage(self) -> itkImageSS3
        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GetReferenceImage(self, *args)

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GetUseReferenceImage(self)

    def SetOutputSpacing(self, _arg):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_SetOutputSpacing(self, _arg)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD3"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GetOutputSpacing(self)

    def SetOutputOrigin(self, _arg):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_SetOutputOrigin(self, _arg)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD3"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GetOutputOrigin(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD33"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GetOutputDirection(self)

    def GetOutputOffset(self):
        r"""GetOutputOffset(self) -> itkOffset3"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GetOutputOffset(self)

    def SetOutputOffset(self, *args):
        r"""
        SetOutputOffset(self, _arg)

        Parameters
        ----------
        _arg: itkOffset3

        SetOutputOffset(self, data)

        Parameters
        ----------
        data: long *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_SetOutputOffset(self, *args)

    def ChangeAll(self):
        r"""ChangeAll(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_ChangeAll(self)

    def ChangeNone(self):
        r"""ChangeNone(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_ChangeNone(self)

    def SetChangeSpacing(self, _arg):
        r"""
        SetChangeSpacing(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_SetChangeSpacing(self, _arg)

    def ChangeSpacingOn(self):
        r"""ChangeSpacingOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_ChangeSpacingOn(self)

    def ChangeSpacingOff(self):
        r"""ChangeSpacingOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_ChangeSpacingOff(self)

    def GetChangeSpacing(self):
        r"""GetChangeSpacing(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GetChangeSpacing(self)

    def SetChangeOrigin(self, _arg):
        r"""
        SetChangeOrigin(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_SetChangeOrigin(self, _arg)

    def ChangeOriginOn(self):
        r"""ChangeOriginOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_ChangeOriginOn(self)

    def ChangeOriginOff(self):
        r"""ChangeOriginOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_ChangeOriginOff(self)

    def GetChangeOrigin(self):
        r"""GetChangeOrigin(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GetChangeOrigin(self)

    def SetChangeDirection(self, _arg):
        r"""
        SetChangeDirection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_SetChangeDirection(self, _arg)

    def ChangeDirectionOn(self):
        r"""ChangeDirectionOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_ChangeDirectionOn(self)

    def ChangeDirectionOff(self):
        r"""ChangeDirectionOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_ChangeDirectionOff(self)

    def GetChangeDirection(self):
        r"""GetChangeDirection(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GetChangeDirection(self)

    def SetChangeRegion(self, _arg):
        r"""
        SetChangeRegion(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_SetChangeRegion(self, _arg)

    def ChangeRegionOn(self):
        r"""ChangeRegionOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_ChangeRegionOn(self)

    def ChangeRegionOff(self):
        r"""ChangeRegionOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_ChangeRegionOff(self)

    def GetChangeRegion(self):
        r"""GetChangeRegion(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GetChangeRegion(self)

    def SetCenterImage(self, _arg):
        r"""
        SetCenterImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_SetCenterImage(self, _arg)

    def CenterImageOn(self):
        r"""CenterImageOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_CenterImageOn(self)

    def CenterImageOff(self):
        r"""CenterImageOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_CenterImageOff(self)

    def GetCenterImage(self):
        r"""GetCenterImage(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GetCenterImage(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GenerateInputRequestedRegion(self)

    def GenerateData(self):
        r"""GenerateData(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_GenerateData(self)
    __swig_destroy__ = _itkChangeInformationImageFilterPython.delete_itkChangeInformationImageFilterISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkChangeInformationImageFilterISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkChangeInformationImageFilterISS3

        Create a new object of the class itkChangeInformationImageFilterISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkChangeInformationImageFilterISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkChangeInformationImageFilterISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkChangeInformationImageFilterISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkChangeInformationImageFilterISS3 in _itkChangeInformationImageFilterPython:
_itkChangeInformationImageFilterPython.itkChangeInformationImageFilterISS3_swigregister(itkChangeInformationImageFilterISS3)

def itkChangeInformationImageFilterIUC2_New():
    return itkChangeInformationImageFilterIUC2.New()

class itkChangeInformationImageFilterIUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkChangeInformationImageFilterIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkChangeInformationImageFilterIUC2_Pointer"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkChangeInformationImageFilterIUC2_Pointer"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_Clone(self)

    def SetReferenceImage(self, image):
        r"""
        SetReferenceImage(self, image)

        Parameters
        ----------
        image: itkImageUC2 *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_SetReferenceImage(self, image)

    def GetModifiableReferenceImage(self):
        r"""GetModifiableReferenceImage(self) -> itkImageUC2"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GetModifiableReferenceImage(self)

    def GetReferenceImage(self, *args):
        r"""
        GetReferenceImage(self) -> itkImageUC2
        GetReferenceImage(self) -> itkImageUC2
        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GetReferenceImage(self, *args)

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GetUseReferenceImage(self)

    def SetOutputSpacing(self, _arg):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_SetOutputSpacing(self, _arg)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD2"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GetOutputSpacing(self)

    def SetOutputOrigin(self, _arg):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_SetOutputOrigin(self, _arg)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD2"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GetOutputOrigin(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD22"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GetOutputDirection(self)

    def GetOutputOffset(self):
        r"""GetOutputOffset(self) -> itkOffset2"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GetOutputOffset(self)

    def SetOutputOffset(self, *args):
        r"""
        SetOutputOffset(self, _arg)

        Parameters
        ----------
        _arg: itkOffset2

        SetOutputOffset(self, data)

        Parameters
        ----------
        data: long *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_SetOutputOffset(self, *args)

    def ChangeAll(self):
        r"""ChangeAll(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_ChangeAll(self)

    def ChangeNone(self):
        r"""ChangeNone(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_ChangeNone(self)

    def SetChangeSpacing(self, _arg):
        r"""
        SetChangeSpacing(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_SetChangeSpacing(self, _arg)

    def ChangeSpacingOn(self):
        r"""ChangeSpacingOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_ChangeSpacingOn(self)

    def ChangeSpacingOff(self):
        r"""ChangeSpacingOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_ChangeSpacingOff(self)

    def GetChangeSpacing(self):
        r"""GetChangeSpacing(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GetChangeSpacing(self)

    def SetChangeOrigin(self, _arg):
        r"""
        SetChangeOrigin(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_SetChangeOrigin(self, _arg)

    def ChangeOriginOn(self):
        r"""ChangeOriginOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_ChangeOriginOn(self)

    def ChangeOriginOff(self):
        r"""ChangeOriginOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_ChangeOriginOff(self)

    def GetChangeOrigin(self):
        r"""GetChangeOrigin(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GetChangeOrigin(self)

    def SetChangeDirection(self, _arg):
        r"""
        SetChangeDirection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_SetChangeDirection(self, _arg)

    def ChangeDirectionOn(self):
        r"""ChangeDirectionOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_ChangeDirectionOn(self)

    def ChangeDirectionOff(self):
        r"""ChangeDirectionOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_ChangeDirectionOff(self)

    def GetChangeDirection(self):
        r"""GetChangeDirection(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GetChangeDirection(self)

    def SetChangeRegion(self, _arg):
        r"""
        SetChangeRegion(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_SetChangeRegion(self, _arg)

    def ChangeRegionOn(self):
        r"""ChangeRegionOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_ChangeRegionOn(self)

    def ChangeRegionOff(self):
        r"""ChangeRegionOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_ChangeRegionOff(self)

    def GetChangeRegion(self):
        r"""GetChangeRegion(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GetChangeRegion(self)

    def SetCenterImage(self, _arg):
        r"""
        SetCenterImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_SetCenterImage(self, _arg)

    def CenterImageOn(self):
        r"""CenterImageOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_CenterImageOn(self)

    def CenterImageOff(self):
        r"""CenterImageOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_CenterImageOff(self)

    def GetCenterImage(self):
        r"""GetCenterImage(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GetCenterImage(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GenerateInputRequestedRegion(self)

    def GenerateData(self):
        r"""GenerateData(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_GenerateData(self)
    __swig_destroy__ = _itkChangeInformationImageFilterPython.delete_itkChangeInformationImageFilterIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkChangeInformationImageFilterIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkChangeInformationImageFilterIUC2

        Create a new object of the class itkChangeInformationImageFilterIUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkChangeInformationImageFilterIUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkChangeInformationImageFilterIUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkChangeInformationImageFilterIUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkChangeInformationImageFilterIUC2 in _itkChangeInformationImageFilterPython:
_itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC2_swigregister(itkChangeInformationImageFilterIUC2)

def itkChangeInformationImageFilterIUC3_New():
    return itkChangeInformationImageFilterIUC3.New()

class itkChangeInformationImageFilterIUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkChangeInformationImageFilterIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkChangeInformationImageFilterIUC3_Pointer"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkChangeInformationImageFilterIUC3_Pointer"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_Clone(self)

    def SetReferenceImage(self, image):
        r"""
        SetReferenceImage(self, image)

        Parameters
        ----------
        image: itkImageUC3 *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_SetReferenceImage(self, image)

    def GetModifiableReferenceImage(self):
        r"""GetModifiableReferenceImage(self) -> itkImageUC3"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GetModifiableReferenceImage(self)

    def GetReferenceImage(self, *args):
        r"""
        GetReferenceImage(self) -> itkImageUC3
        GetReferenceImage(self) -> itkImageUC3
        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GetReferenceImage(self, *args)

    def SetUseReferenceImage(self, _arg):
        r"""
        SetUseReferenceImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_SetUseReferenceImage(self, _arg)

    def UseReferenceImageOn(self):
        r"""UseReferenceImageOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_UseReferenceImageOn(self)

    def UseReferenceImageOff(self):
        r"""UseReferenceImageOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_UseReferenceImageOff(self)

    def GetUseReferenceImage(self):
        r"""GetUseReferenceImage(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GetUseReferenceImage(self)

    def SetOutputSpacing(self, _arg):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_SetOutputSpacing(self, _arg)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD3"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GetOutputSpacing(self)

    def SetOutputOrigin(self, _arg):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_SetOutputOrigin(self, _arg)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD3"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GetOutputOrigin(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD33"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GetOutputDirection(self)

    def GetOutputOffset(self):
        r"""GetOutputOffset(self) -> itkOffset3"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GetOutputOffset(self)

    def SetOutputOffset(self, *args):
        r"""
        SetOutputOffset(self, _arg)

        Parameters
        ----------
        _arg: itkOffset3

        SetOutputOffset(self, data)

        Parameters
        ----------
        data: long *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_SetOutputOffset(self, *args)

    def ChangeAll(self):
        r"""ChangeAll(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_ChangeAll(self)

    def ChangeNone(self):
        r"""ChangeNone(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_ChangeNone(self)

    def SetChangeSpacing(self, _arg):
        r"""
        SetChangeSpacing(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_SetChangeSpacing(self, _arg)

    def ChangeSpacingOn(self):
        r"""ChangeSpacingOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_ChangeSpacingOn(self)

    def ChangeSpacingOff(self):
        r"""ChangeSpacingOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_ChangeSpacingOff(self)

    def GetChangeSpacing(self):
        r"""GetChangeSpacing(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GetChangeSpacing(self)

    def SetChangeOrigin(self, _arg):
        r"""
        SetChangeOrigin(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_SetChangeOrigin(self, _arg)

    def ChangeOriginOn(self):
        r"""ChangeOriginOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_ChangeOriginOn(self)

    def ChangeOriginOff(self):
        r"""ChangeOriginOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_ChangeOriginOff(self)

    def GetChangeOrigin(self):
        r"""GetChangeOrigin(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GetChangeOrigin(self)

    def SetChangeDirection(self, _arg):
        r"""
        SetChangeDirection(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_SetChangeDirection(self, _arg)

    def ChangeDirectionOn(self):
        r"""ChangeDirectionOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_ChangeDirectionOn(self)

    def ChangeDirectionOff(self):
        r"""ChangeDirectionOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_ChangeDirectionOff(self)

    def GetChangeDirection(self):
        r"""GetChangeDirection(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GetChangeDirection(self)

    def SetChangeRegion(self, _arg):
        r"""
        SetChangeRegion(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_SetChangeRegion(self, _arg)

    def ChangeRegionOn(self):
        r"""ChangeRegionOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_ChangeRegionOn(self)

    def ChangeRegionOff(self):
        r"""ChangeRegionOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_ChangeRegionOff(self)

    def GetChangeRegion(self):
        r"""GetChangeRegion(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GetChangeRegion(self)

    def SetCenterImage(self, _arg):
        r"""
        SetCenterImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_SetCenterImage(self, _arg)

    def CenterImageOn(self):
        r"""CenterImageOn(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_CenterImageOn(self)

    def CenterImageOff(self):
        r"""CenterImageOff(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_CenterImageOff(self)

    def GetCenterImage(self):
        r"""GetCenterImage(self) -> bool"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GetCenterImage(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GenerateInputRequestedRegion(self)

    def GenerateData(self):
        r"""GenerateData(self)"""
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_GenerateData(self)
    __swig_destroy__ = _itkChangeInformationImageFilterPython.delete_itkChangeInformationImageFilterIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkChangeInformationImageFilterIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkChangeInformationImageFilterIUC3

        Create a new object of the class itkChangeInformationImageFilterIUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkChangeInformationImageFilterIUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkChangeInformationImageFilterIUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkChangeInformationImageFilterIUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkChangeInformationImageFilterIUC3 in _itkChangeInformationImageFilterPython:
_itkChangeInformationImageFilterPython.itkChangeInformationImageFilterIUC3_swigregister(itkChangeInformationImageFilterIUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def change_information_image_filter(*args: itkt.ImageLike,  reference_image: itkt.Image=..., use_reference_image: bool=..., output_spacing: Sequence[float]=..., output_origin: Sequence[float]=..., output_direction=..., output_offset: Sequence[int]=..., change_spacing: bool=..., change_origin: bool=..., change_direction: bool=..., change_region: bool=..., center_image: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ChangeInformationImageFilter"""
    import itk

    kwarg_typehints = { 'reference_image':reference_image,'use_reference_image':use_reference_image,'output_spacing':output_spacing,'output_origin':output_origin,'output_direction':output_direction,'output_offset':output_offset,'change_spacing':change_spacing,'change_origin':change_origin,'change_direction':change_direction,'change_region':change_region,'center_image':center_image }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ChangeInformationImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def change_information_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageGrid.ChangeInformationImageFilter
    change_information_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    change_information_image_filter.__doc__ = filter_object.__doc__



